bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 36. Aventiure
___________________________________________________ #### Aventivr wie div chvnigin den sal beraiten hiez
| ### v bindet ab die helme sprach Hagne der degen ### ich vn– min geselle svln iwer phlegen ### vn– wellent ez versvochen noch die Eceln man ### so warn ich mine herren so ich aller schierst kan
###### 2019 | ### Do entwafende daz hovbet manich ritter gvot ### si sazen vf die wunden die vor in in daz blvot ### warn zvo dem tode von ir handen komen ### da wart der edeln geste vil boese govme genomen
###### 2020 | ### Noch vor dem abende schvof der kvnich daz ### vn– ovch div kvniginne daz ez versvochten baz ### die hvnischen reken der sach man vor im stan ### noch wol zweinzich tvsent die mvosen da ze strite gan
###### 2021 | ### Sich hvop ein stvrm herte zvo den gesten san ### Dancwart Hagnen brvoder der vil snelle man ### spranch von sinen herren zen vienden fvr die tvr ### man wand er wer estorben er kom gesvnt wol derfvr
###### 2022 | ### Der herte strit werte vntz in div naht benam ### do werten sich die geste so gvoten helden zam ### der Eceln manne den svmerlangen tach ### hey waz gvoter degne vor in weige gelach
###### 2023 | ### Ze einen svnewenden der groze mort geschach ### daz div vrowe Kriemhilt ir herzeleit errach ### an ir nehsten magen vn– an vil manigem man ### da von der kvnich Ecel vrovde nimmer me gewan [82b]
###### 2024 | ### In waz des tages zervnnen do gie in sorge not ### si dahten daz in bezzer wer ein kvrzer tot ### danne lange da ze quæle ein vf vngefvegiv leit ### eines vrides do gerten die stolzen rittere gemeit
###### 2025 | ### Si baten daz man brehte den kvnich zvo in dar ### die blvotvarwen helde vnd ovch harnaschvar ### traten zvo dem hvse vnd die dri kvnige her ### si enwessen wem ze klagenne ir vil grozlichiv ser
###### 2026 | ### Ecel vnd Kriemhilt komen beidiv dar ### daz lant waz ir eigen des merte sich ir schar ### er sprach zvo den gesten nv saget waz welt ir min ### ir went vride gewinnen daz kvnde mvelich gesin
###### 2027 | ### vf schaden also grozen als ir mir habet getan ### ir svltez niht geniezen sol ich min leben han ### min kint daz ir mir slvoget vn– vil der mage min ### vride vnd svone sol iv vil gar versaget sin
###### 2028 | ### Svs antwurte Gvnther des twang vns groziv not ### allez min gesinde lach vor dienen helden tot ### an der herberge wie hete ich daz versolt ### ich kom zvo dir vf driwe ich wande daz dv mir werst holt
###### 2029 | ### Do sprach von Bvrgonden Geyselher daz kint ### ir Ezeln helde die noch lebende sint ### waz wizet ir mir reken waz het ich iv getan ### wan ich frivntliche in ditze lant geriten han
###### 2030 | ### Si sprachen diner gvote st al div bvrk vol ### mit iamer zvo dem lande ia gvnde wir dir wol ### daz dv nie komen werest von Wurmz vber Rin ### daz lant hat ir verweiset dv vnd die brveder din
###### 2031 | ### Do sprach in zornes mvote Gvnther der degen ### welt ir ditze starcke ze einer svone legen ### mit vns ellenden reken daz ist vns beidenthalben gvot ### ez ist gar an schvlde swaz vns Ezel getvot
###### 2032 | ### Do sprach der wirt zen gesten min vnd iwer læit ### div sint vngeliche div starke arebeit ### des schaden zvo den shanden die ich hie han genomen ### des sol iwer deheiner nimmer hinne komen
###### 2033 | ### Do sprach zvo dem kvnige der starcke Gernot ### so sol iv got gebieten daz ir frivntlichen tvot ### slaht vns ellende vn– lat vns zvo iv gan ### hin nider an die weite daz ist iv ere getan
###### 2034 | ### Swaz vns da geschehen chvnne daz lat da kvrtz ergan ### ir hapt so vil gesvnder vnt tvrrens vns bestan ### daz si vns stvrm mvede lazent niht genesen ### wie lange svl wir reken in disen arebeiten wesen
###### 2035 | ### Die Ezeln reken die heten ez nach getan ### daz si si wolden lazzen fvr den palas gan ### daz gehorte Kriemhilt ez waz ir grimme leit ### dez wart den ellenden der fride gahes widersait
###### 2036 | ### Næina ziere reken des ir da habet mvot ### ich rate an rehten triwen daz ir dez niht entvot [83a] ### daz ir die mortrezen iht lazet fvr den sal ### so mvozen iwer mage liden den toetlichen val
###### 2037 | ### Ob ir nv niemen lebte wan div voten kinde ### die minen edelen brvoder vn– chomens an den wint ### erchvolent in die ringe so sit ir alle verlorn ### ezn wir den chvoner degene ze werlde nie geborn
###### 2038 | ### Do sprach der ivnge Giselher vil schoeniv swester min ### des getrovt ich vil vbel do dv mich vber Rin ### ladeste her ze lande in dise groze not ### wie han ich an den Hvenen hie verdienet den tot
###### 2039 | ### Ich waz dir ie getriwe nie tet ich dir læit ### vf solhen gedingen her ze hove ich reit ### daz dv mir holt werest vil liebiv swester min ### bedenche an vns genade ez mach niht anders gesin
###### 2040 | ### Ich en mag iv niht genaden vngenade ich han ### mir hat von Tronge Hagene so groziv lait ge ### ez ist vil vnversvenet die wile ich han den lip ### ir mvestes alle engelten sprach daz Ezeln wip
###### 2041 | ### Welt ir mir Hagen æinen ze einem gisel geben ### so wil ich niht versprechen ich en welle iv lazen leben ### wan ir sit mine brveder vn– einer mvoter chint ### so red ichs nach der svone mit disen helden die hie sint
###### 2042 | ### Nvne welle got von himel sprach do Gernot ### ob vnser tvsent weren wir legen alle tot ### der sippe diner mage e wir den einen man ### geben hie ze gisel ez wirt nimmer getan
###### 2043 | ### Wir mvosen doch ersterben so sprach do Gyselher ### vns enscheidet niemen von riterlicher wer ### swer gern mit vns vehte wir sin et aber hie ### wan ich deheinen minen frivnt an triwen nie verlie
###### 2044 | ### Do sprach <der> chvone Dancwart im zeme niht ze dagen ### ia enstet niht eime min brvoder Hagen ### die hie den vride versprechent ez moht in werden leit ### des bringe wir ivch inne daz si iv werlich geseit
###### 2045 | ### Do sprach div kvniginne ir helde vil gemeit ### nv get der stiege naher vn– rechet miniv leit ### daz wil ich immer dienen als ich von rehte sol ### der Hagen vbermvote der geloen ich im wol
###### 2046 | ### Lat einem voz dem gademe niht komen vber al ### so heiz ich viern enden zvnden an den sal ### so werdent wol errochen elliv miniv læit ### die Ezeln reken die wrden alle schiere bereit
###### 2047 | ### Die noh hie vze stvonden die tribens in den sal ### mit slegen vn– mit schvzen des wart groz der schal ### doch wolden nie gescheiden die fvrsten vn– ir man ### si kvnden von ir triwe an ein ander niht verlan
###### 2048 | ### Den sal den hiez do zvnden daz Ezeln wip ### do qualte man mit fivr den helden da den lip ### daz hvs kom von einem winde vil balde allez verbran ### ich wene volk enhæinez grozer angest ie gewan [83b]
###### 2049 | ### Genvoge riefen drinne owe dirre not ### wir mehten michel gerner sin in stvrme tot ### ez mehte got derbarmen wie si wir alle vlorn ### nv richet vngefvoge div kvniginne ir zorn
###### 2050 | ### Ir einer sprach dar inne wir mvezzen ligen tot ### waz hilfet vns daz grvezen daz vns der kvnich enpot ### mir tvot von starcher hitze der dvrst so rehte we ### daz wene min leben in disen sorgen schier zerge
###### 2051 | ### Do sprach von Trongen Hagen der riter gvot ### swen twinge dvrstens not <der> trincke hie daz blvot ### daz man solher hitze noh bezzer denne win ### ez enmach et an disen ziten niht bezzer gesein
###### 2052 | ### Do gie der recken einer da er æinen toten vant ### er chniet im zvo der wunden den helm er abe gebant ### do begvnde er trinchen daz fliezende blvot ### swie vngewon er sin were ez dvhte in grozlichen gvot
###### 2053 | ### Nv lone iv got her Hagen sprach der mvede man ### daz ich von iwer lere so wol getrvnken han ### mir ist noch geschenket vil selten bezzer win ### lebe ich deheine wile ich sol iv immer wege sin
###### 2054 | ### Do die andern daz gehorten daz ez in dvhte gvot ### do wart ir michels mere die trvnken ovch daz blvot ### da von gewan vil krefte ir etlichez lip ### des engalt an lieben frivnden sit vil wetlichez wip
###### 2055 | ### Daz fivr viel genote vf si in den sal ### do læiten sis mit schilten von in hintze tal ### der ravch vn– ovch die hitze in taten beidiv we ### ich wen so grozer iamer an helden immer mer erge
###### 2056 | ### Do sprach von Tronge Hagene stet zvo des sales want ### lat niht die brende vallen vf iwer helm bant ### tret si mit den fvezen tiefer in daz blvot ### ez ist ein vbel hochzit die vns div kvniginne tvot
###### 2057 | ### In so getanem læide in doch der naht zeran ### noch stvont vor dem hvse der chvene spilman ### vnd Hagen sin geselle gelæint vber rant ### si warten schaden mere von den vz Ezeln lant
###### 2058 | ### Do sprach der videlere nv ge wir in den sal ### so wenent des die Hvenen daz wir sin vber al ### tot von dirre quale div an vns ist getan ### si sehent vns noch begegene in strite ir eteslichen gan
###### 2059 | ### Do sprach von Bvrgonden Gyselhers <daz> kint ### ich wen ez iagen welle sich hebet ein chveler wint ### nv laz vns got von himel noch lieber zit geleben ### vns hat min swester Kriemhilt ein arge hohgezit geben
###### 2060 | ### Do sprach aber æiner ich chivse nv den tack ### sit daz bezzer wesen niene mach ### so wafent ir ivch helde gedenket an den lip ### ia chvmt vns aber schiere des kvnich Ezeln wip
###### 2061 | ### Der wirt wolde wenen die geste weren tot [84a] ### von ir arbeite vnd von des fivrs not ### do lebt ir noch dar inne sehs hvndert kvener man ### daz nie kvnich deheiner bezzer degene gewan
###### 2062 | ### Der ellenden hvete het wol ersehen ### daz noch die geste lebten swie vil in was geschehen ### ze schaden vn– ze leide den herren vnd ir man ### man sach si wol gesvnde noh in dem gademe gan
###### 2063 | ### Man sagte Kriemhilt ir were vil genesen ### do sprach div kvniginne daz mohte nimmer wesen ### daz ir deheiner lebte von des fivrs not ### ich wil des baz getrowen daz si alle ligen tot
###### 2064 | ### Noch genesen gerne die fvrsten vnde ir man ### ob noch ieman wolte genade an in began ### des enchvnden si niht vinden an den von Hvone lant ### do rachen si ir sterben mit vil williger hant
###### 2065 | ### Des tages wider morgen grvezen man in bot ### mit hertem vrlivge des chomen helde in not ### do wart zvo in geschozzen vil manich starcker ger ### sich werten riterliche die rechen chven vnd her
###### 2066 | ### Dem Ezeln gesinde erweget was der mvot ### daz si wolten dienen daz Kriemhilt gvot ### dar zvo si wolden leisten daz in der kvnich gebot ### da mvose maniger schiere von in kiesen den tot
###### 2067 | ### Von geheize vnd ovch von gabe man mohte wunder sagen ### si hiez golt daz rote dar zvo mit schilden tragen ### si gab ez swer sin rvochte vn– ez wolte enphan ### iane wart nie grozer solden vf viende mer getan
###### 2068 | ### Ein michel teil der rechen dar zvo gewafent gie ### do sprach der chvene Volker wir sin et aber hie ### ich gesach vf vehten nie helde gerner chomen ### di daz golt des kvniges vns ze vare hant genomen
###### 2069 | ### Do riefen ir genvege naher helde baz ### daz wir da svln verenden nv tvon bi zite daz ### hie belibet niemen wan der doch sterben sol ### do sach man schier in schilde stechen geschvzze vol
###### 2070 | ### Waz mag ich sagen mere wol zwelf hvndert man ### di versvochten ez vil sere wider vnd dan ### do chvlten mit den wunden die geste wol ir mvot ### ezen mohte nieman scheiden des sach man fliezen da daz blvot
###### 2071 | ### von verchtief wunden des wart da vil geslagen ### islichen nach den frivnden horte man do klagen ### die biderben stvrben alle dem richem chvnige her ### des heten holde mage nach in grozlichiv ser

<<< Übersicht <<< vorige Seite nächste Seite >>>